Index: c/src/lib/libcpu/mips/ChangeLog
===================================================================
--- c/src/lib/libcpu/mips/ChangeLog	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/ChangeLog	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -1,2 +1,10 @@
+2004-03-30	Ralf Corsepius <ralf_corsepius@rtems.org>
+
+	* clock/ckinit.c, clock/clock.h, mongoosev/duart/mg5uart.c,
+	mongoosev/duart/mg5uart.h, mongoosev/duart/mg5uart_reg.c,
+	mongoosev/include/mongoose-v.h, mongoosev/vectorisrs/vectorisrs.c,
+	shared/interrupts/vectorexceptions.c, timer/timer.c,
+	tx39/include/tx3904.h: Convert to using c99 fixed size types.
+
 2004-03-26	Ralf Corsepius <ralf_corsepius@rtems.org>
 
Index: c/src/lib/libcpu/mips/clock/ckinit.c
===================================================================
--- c/src/lib/libcpu/mips/clock/ckinit.c	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/clock/ckinit.c	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -75,5 +75,5 @@
  */
 
-volatile rtems_unsigned32 Clock_driver_ticks;
+volatile uint32_t   Clock_driver_ticks;
 
 /*
@@ -85,5 +85,5 @@
  */
 
-rtems_unsigned32 Clock_isrs;              /* ISRs until next tick */
+uint32_t   Clock_isrs;              /* ISRs until next tick */
 
 /*
@@ -102,5 +102,5 @@
 void Clock_exit( void );
 
-static unsigned32 mips_timer_rate = 0;
+static uint32_t   mips_timer_rate = 0;
 
 /*
@@ -218,5 +218,5 @@
 )
 {
-    rtems_unsigned32 isrlevel;
+    uint32_t   isrlevel;
     rtems_libio_ioctl_args_t *args = pargp;
  
Index: c/src/lib/libcpu/mips/clock/clock.h
===================================================================
--- c/src/lib/libcpu/mips/clock/clock.h	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/clock/clock.h	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -23,3 +23,3 @@
 /* @(#)clock.h       08/20/96     1.2 */
 
-extern void mips_set_timer( unsigned32 timer_clock_interval );
+extern void mips_set_timer( uint32_t   timer_clock_interval );
Index: c/src/lib/libcpu/mips/mongoosev/duart/mg5uart.c
===================================================================
--- c/src/lib/libcpu/mips/mongoosev/duart/mg5uart.c	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/mongoosev/duart/mg5uart.c	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -82,9 +82,9 @@
 )
 {
-  unsigned32             pMG5UART_port;
-  unsigned32             pMG5UART;
-  unsigned32             cmd, cmdSave;
-  unsigned32             baudcmd;
-  unsigned32             shift;
+  uint32_t               pMG5UART_port;
+  uint32_t               pMG5UART;
+  uint32_t               cmd, cmdSave;
+  uint32_t               baudcmd;
+  uint32_t               shift;
   rtems_interrupt_level  Irql;
 
@@ -221,8 +221,8 @@
 MG5UART_STATIC void mg5uart_init(int minor)
 {
-  unsigned32            pMG5UART_port;
-  unsigned32            pMG5UART;
-  unsigned32		cmdSave;
-  unsigned32		shift;
+  uint32_t              pMG5UART_port;
+  uint32_t              pMG5UART;
+  uint32_t  		cmdSave;
+  uint32_t  		shift;
 
   mg5uart_context        *pmg5uartContext;
@@ -270,10 +270,10 @@
 )
 {
-  unsigned32    pMG5UART;
-  unsigned32    pMG5UART_port;
-  unsigned32	vector;
-  unsigned32    cmd, cmdSave;
-  unsigned32    baudcmd;
-  unsigned32    shift;
+  uint32_t      pMG5UART;
+  uint32_t      pMG5UART_port;
+  uint32_t  	vector;
+  uint32_t      cmd, cmdSave;
+  uint32_t      baudcmd;
+  uint32_t      shift;
 
   rtems_interrupt_level  Irql;
@@ -327,8 +327,8 @@
 )
 {
-  unsigned32    pMG5UART;
-  unsigned32    pMG5UART_port;
-  unsigned32	cmd, cmdSave;
-  unsigned32    shift;
+  uint32_t      pMG5UART;
+  uint32_t      pMG5UART_port;
+  uint32_t  	cmd, cmdSave;
+  uint32_t      shift;
   rtems_interrupt_level  Irql;
 
@@ -375,7 +375,7 @@
 )
 {
-  unsigned32              pMG5UART;
-  unsigned32              pMG5UART_port;
-  unsigned32              status;
+  uint32_t                pMG5UART;
+  uint32_t                pMG5UART_port;
+  uint32_t                status;
   int                     shift;
   int                     timeout;
@@ -475,8 +475,8 @@
 MG5UART_STATIC void mg5uart_process_isr_rx_error(
    int  minor, 
-   unsigned32 mask 
-)
-{
-  unsigned32              pMG5UART;
+   uint32_t   mask 
+)
+{
+  uint32_t                pMG5UART;
   int                     shift;
 
@@ -520,8 +520,8 @@
 MG5UART_STATIC void mg5uart_process_tx_isr(
    int        minor,
-   unsigned32 source
-)
-{
-   unsigned32      pMG5UART;
+   uint32_t   source
+)
+{
+   uint32_t        pMG5UART;
    int             shift;
    
@@ -580,5 +580,5 @@
 )
 {
-  unsigned32              pMG5UART_port;
+  uint32_t                pMG5UART_port;
   unsigned char           c;
 
@@ -639,6 +639,6 @@
 )
 {
-  unsigned32      Irql;
-  unsigned32      pMG5UART_port;
+  uint32_t        Irql;
+  uint32_t        pMG5UART_port;
 
   pMG5UART_port = Console_Port_Tbl[minor].ulCtrlPort2;
@@ -713,8 +713,8 @@
 )
 {
-  unsigned32              pMG5UART;
-  unsigned32              pMG5UART_port;
-  unsigned32              status;
-  unsigned32              tmp,shift;
+  uint32_t                pMG5UART;
+  uint32_t                pMG5UART_port;
+  uint32_t                status;
+  uint32_t                tmp,shift;
 
   pMG5UART      = Console_Port_Tbl[minor].ulCtrlPort1;
@@ -755,7 +755,7 @@
 )
 {
-  rtems_unsigned32 clock;
-  rtems_unsigned32 tmp_code;
-  rtems_unsigned32 baud_requested;
+  uint32_t   clock;
+  uint32_t   tmp_code;
+  uint32_t   baud_requested;
 
   baud_requested = baud & CBAUD;
@@ -765,5 +765,5 @@
   baud_requested = termios_baud_to_number( baud_requested );
 
-  clock = (rtems_unsigned32) Console_Port_Tbl[minor].ulClock;
+  clock = (uint32_t  ) Console_Port_Tbl[minor].ulClock;
   if (!clock)
     rtems_fatal_error_occurred(RTEMS_INVALID_NUMBER);
@@ -811,7 +811,7 @@
 )
 {
-  unsigned32            pMG5UART;
-  unsigned32		maskSave;
-  unsigned32            shift;
+  uint32_t              pMG5UART;
+  uint32_t  		maskSave;
+  uint32_t              shift;
   rtems_interrupt_level  Irql;
 
Index: c/src/lib/libcpu/mips/mongoosev/duart/mg5uart.h
===================================================================
--- c/src/lib/libcpu/mips/mongoosev/duart/mg5uart.h	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/mongoosev/duart/mg5uart.h	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -83,13 +83,13 @@
  */
 
-unsigned32 mg5uart_get_register(    /* registers are on 32-bit boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as word             */
-  unsigned32  ucRegNum
+uint32_t   mg5uart_get_register(    /* registers are on 32-bit boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as word             */
+  uint32_t    ucRegNum
 );
 
 void  mg5uart_set_register(
-  unsigned32  ulCtrlPort,
-  unsigned32  ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint32_t    ucRegNum,
+  uint32_t    ucData
 );
 
Index: c/src/lib/libcpu/mips/mongoosev/include/mongoose-v.h
===================================================================
--- c/src/lib/libcpu/mips/mongoosev/include/mongoose-v.h	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/mongoosev/include/mongoose-v.h	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -21,14 +21,14 @@
 
 #define MONGOOSEV_READ( _base ) \
-  ( *((volatile unsigned32 *)(_base)) )
+  ( *((volatile uint32_t   *)(_base)) )
 
 #define MONGOOSEV_WRITE( _base, _value ) \
-  ( *((volatile unsigned32 *)(_base)) = (_value) )
+  ( *((volatile uint32_t   *)(_base)) = (_value) )
 
 #define MONGOOSEV_READ_REGISTER( _base, _register ) \
-  ( *((volatile unsigned32 *)((_base) + (_register))) )
+  ( *((volatile uint32_t   *)((_base) + (_register))) )
 
 #define MONGOOSEV_WRITE_REGISTER( _base, _register, _value ) \
-  ( *((volatile unsigned32 *)((_base) + (_register))) = (_value) )
+  ( *((volatile uint32_t   *)((_base) + (_register))) = (_value) )
 
 
Index: c/src/lib/libcpu/mips/mongoosev/vectorisrs/vectorisrs.c
===================================================================
--- c/src/lib/libcpu/mips/mongoosev/vectorisrs/vectorisrs.c	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/mongoosev/vectorisrs/vectorisrs.c	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -42,9 +42,9 @@
 /* userspace routine to assert either software interrupt */
 
-int assertSoftwareInterrupt( unsigned32 n )
+int assertSoftwareInterrupt( uint32_t   n )
 {
    if( n<2 )
    {
-      unsigned32 c;
+      uint32_t   c;
 
       mips_get_cause(c);
@@ -77,6 +77,6 @@
 
 #if 0
-#define SET_ISR_FLAG( offset )	*((unsigned32 *)(0x8001e000+offset)) = 1;
-#define CLR_ISR_FLAG( offset )	*((unsigned32 *)(0x8001e000+offset)) = 0;
+#define SET_ISR_FLAG( offset )	*((uint32_t   *)(0x8001e000+offset)) = 1;
+#define CLR_ISR_FLAG( offset )	*((uint32_t   *)(0x8001e000+offset)) = 0;
 #else
 #define SET_ISR_FLAG( offset )
@@ -89,8 +89,8 @@
 
 
-static volatile unsigned32 _ivcause, _ivsr;
-
-
-static unsigned32 READ_CAUSE(void) 
+static volatile uint32_t   _ivcause, _ivsr;
+
+
+static uint32_t   READ_CAUSE(void) 
 {
    mips_get_cause( _ivcause );
@@ -117,5 +117,5 @@
 void mips_vector_isr_handlers( CPU_Interrupt_frame *frame )
 {
-   unsigned32	cshifted;
+   uint32_t  	cshifted;
 
    /* mips_get_sr( sr ); */
@@ -191,7 +191,7 @@
    if ( cshifted & 0x80 )       /* IP[5] ==> INT5, peripheral interrupt */
    {
-      unsigned32  bit;
-      unsigned32  pf_icr, pf_mask, pf_reset = 0;
-      unsigned32  i, m;
+      uint32_t    bit;
+      uint32_t    pf_icr, pf_mask, pf_reset = 0;
+      uint32_t    i, m;
 
       pf_icr = MONGOOSEV_READ( MONGOOSEV_PERIPHERAL_FUNCTION_INTERRUPT_CAUSE_REGISTER );
Index: c/src/lib/libcpu/mips/shared/interrupts/vectorexceptions.c
===================================================================
--- c/src/lib/libcpu/mips/shared/interrupts/vectorexceptions.c	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/shared/interrupts/vectorexceptions.c	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -72,5 +72,5 @@
   int   i, j;
 
-  frame_u32 = (unsigned32 *)frame;
+  frame_u32 = (uint32_t   *)frame;
   for(i=0; dumpregs[i].offset > -1; i++)
   {
@@ -113,6 +113,6 @@
 void mips_vector_exceptions( CPU_Interrupt_frame *frame )
 {
-  unsigned32 cause;
-  unsigned32 exc;
+  uint32_t   cause;
+  uint32_t   exc;
 
   mips_get_cause( cause );
Index: c/src/lib/libcpu/mips/timer/timer.c
===================================================================
--- c/src/lib/libcpu/mips/timer/timer.c	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/timer/timer.c	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -51,8 +51,8 @@
 #define TIMER_MAX_VALUE 0xffffffff
 
-extern unsigned32 mips_read_timer( void );
+extern uint32_t   mips_read_timer( void );
 
 static rtems_boolean Timer_driver_Find_average_overhead;
-static unsigned32 Timer_initial_value = 0;
+static uint32_t   Timer_initial_value = 0;
 
 void Timer_initialize( void )
@@ -83,6 +83,6 @@
 int Read_timer( void )
 {
-  unsigned64 clicks;
-  unsigned32 total;
+  uint64_t   clicks;
+  uint32_t   total;
 
   /*
Index: c/src/lib/libcpu/mips/tx39/include/tx3904.h
===================================================================
--- c/src/lib/libcpu/mips/tx39/include/tx3904.h	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/tx39/include/tx3904.h	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -29,8 +29,8 @@
 
 #define TX3904_TIMER_READ( _base, _register ) \
-  *((volatile unsigned32 *)((_base) + (_register)))
+  *((volatile uint32_t   *)((_base) + (_register)))
 
 #define TX3904_TIMER_WRITE( _base, _register, _value ) \
-  *((volatile unsigned32 *)((_base) + (_register))) = (_value)
+  *((volatile uint32_t   *)((_base) + (_register))) = (_value)
 
 /*

Index: c/src/lib/libcpu/mips/mongoosev/duart/mg5uart_reg.c
===================================================================
--- c/src/lib/libcpu/mips/mongoosev/duart/mg5uart_reg.c	(revision e96a950bcf9953c0c0474fb21ec2af9c260e3668)
+++ c/src/lib/libcpu/mips/mongoosev/duart/mg5uart_reg.c	(revision 35f9701021dce847972c2ebe0d606532db891556)
@@ -3,5 +3,5 @@
  *  used with the mg5uart chip if accesses to the chip are as follows:
  *
  *    + registers are accessed as unsigned32's
  *    + registers are only u32-aligned (no address gaps)
  *
@@ -21,5 +21,5 @@
 #define _MG5UART_MULTIPLIER 1
 #define _MG5UART_NAME(_X) _X
-#define _MG5UART_TYPE unsigned32
+#define _MG5UART_TYPE uint32_t  
 #endif
 
@@ -31,7 +31,7 @@
  */
 
-unsigned8 _MG5UART_NAME(mg5uart_get_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum
+uint8_t   _MG5UART_NAME(mg5uart_get_register)(
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum
 )
 {
@@ -48,7 +48,7 @@
 
 void  _MG5UART_NAME(mg5uart_set_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 )
 {
@@ -3,5 +3,5 @@
  *  used with the mg5uart chip if accesses to the chip are as follows:
  *
- *    + registers are accessed as unsigned32's
+ *    + registers are accessed as uint32_t  's
  *    + registers are only u32-aligned (no address gaps)
  *